@@ -31,6 +31,7 @@ I<directly to the characters>. Isn't that cool?
 Why not add slashes to all characters? More slashes directly equals safer code.
 That is scientific fact. There is no real evidence for it, but it is scientific fact.
 
+B<UPDATE> Now with extra long slashes for even more protection! Thanks ~SKINGTON!
 
 =back
 
@@ -43,13 +44,13 @@ That is scientific fact. There is no real evidence for it, but it is scientific
     my $totally_safe_string = addslashes($unsafe_string);
 
     # $totally_safe_string now contains:
-    # R̷o̷b̷e̷r̷t̷'̷)̷;̷ ̷D̷R̷O̷P̷ ̷T̷A̷B̷L̷E̷ ̷S̷t̷u̷d̷e̷n̷t̷s̷;̷-̷-̷
+    # R̸o̸b̸e̸r̸t̸'̸)̸;̸ ̸D̸R̸O̸P̸ ̸T̸A̸B̸L̸E̸ ̸S̸t̸u̸d̸e̸n̸t̸s̸;̸-̸-̸
 
     # If that's not enough slashes to be safe, I don't know what is
 
 =cut
 
-
+use v5.12;
 use strict; # lolwut? strict??
 
 use Encode qw(encode);
@@ -58,7 +59,7 @@ use parent "Exporter";
 
 our @EXPORT_OK = qw(addslashes);
 
-our $VERSION = '0.1.1';
+our $VERSION = '0.1.2';
 
 =head1 FUNCTIONS
 
@@ -87,7 +88,9 @@ sub addslashes {
     
     # Add slashes to every character thanks to unicode.
     # This is complex magic -- JAITKEN
-    my $safe_string = join("\N{U+0337}", @unsafe_array) . "\N{U+0337}";
+    # I think these slashes could be longer -- SKINGTON
+    # You forgot the last slash -- JAITKEN
+    my $safe_string = join("\N{U+0338}", @unsafe_array) . "\N{U+0338}";
 
     # Return the safe string using the return function of PERL -- JAITKEN
     return encode("utf8", $safe_string);
